summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:03:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:03:41 -0600
commit17678d65de293ae9a8b077b5c0bc3f493c617f8b (patch)
treeb4131182c75a7a638f626bc3b9415b6f47ff680e
parent522c7294f06d294c77bc1ea7d0dec4b371c43373 (diff)
downloadbasket-17678d65de293ae9a8b077b5c0bc3f493c617f8b.tar.gz
basket-17678d65de293ae9a8b077b5c0bc3f493c617f8b.zip
Rename obsolete tq methods to standard names
-rw-r--r--src/basket.cpp36
-rw-r--r--src/basketproperties.cpp2
-rw-r--r--src/debugwindow.cpp6
-rw-r--r--src/debugwindow.h2
-rw-r--r--src/focusedwidgets.cpp4
-rw-r--r--src/kcolorcombo2.cpp14
-rw-r--r--src/kcolorcombo2.h2
-rw-r--r--src/kicondialog.cpp2
-rw-r--r--src/kicondialogui.ui4
-rw-r--r--src/likeback.cpp10
-rw-r--r--src/linklabel.cpp22
-rw-r--r--src/newbasketdialog.cpp22
-rw-r--r--src/note.cpp24
-rw-r--r--src/note.h4
-rw-r--r--src/notecontent.cpp4
-rw-r--r--src/notecontent.h20
-rw-r--r--src/notedrag.cpp4
-rw-r--r--src/noteedit.cpp32
-rw-r--r--src/password.cpp4
-rw-r--r--src/passwordlayout.ui2
-rw-r--r--src/regiongrabber.cpp2
-rw-r--r--src/settings.cpp64
-rw-r--r--src/softwareimporters.cpp2
-rw-r--r--src/systemtray.cpp4
-rw-r--r--src/tag.cpp28
-rw-r--r--src/tagsedit.cpp6
-rw-r--r--src/variouswidgets.cpp6
27 files changed, 166 insertions, 166 deletions
diff --git a/src/basket.cpp b/src/basket.cpp
index 078a6c4..41ac42c 100644
--- a/src/basket.cpp
+++ b/src/basket.cpp
@@ -987,7 +987,7 @@ void Basket::setDisposition(int disposition, int columnCount)
}
} else if (currentDisposition == COLUMNS_LAYOUT && (disposition == FREE_LAYOUT || disposition == MINDMAPS_LAYOUT)) {
Note *column = firstNote();
- m_columnsCount = 0; // Now, so relayoutNotes() will not retqlayout the free notes as if they were columns!
+ m_columnsCount = 0; // Now, so relayoutNotes() will not relayout the free notes as if they were columns!
while (column) {
// Move all childs on the first level:
Note *nextColumn = column->next();
@@ -1854,7 +1854,7 @@ void Basket::clickedToInsert(TQMouseEvent *event, Note *clicked, /*Note::Zone*/i
{
Note *note;
if (event->button() == Qt::MidButton)
- note = NoteFactory::dropNote(KApplication::tqclipboard()->data(TQClipboard::Selection), this);
+ note = NoteFactory::dropNote(KApplication::clipboard()->data(TQClipboard::Selection), this);
else
note = NoteFactory::createNoteText("", this);
@@ -2075,7 +2075,7 @@ void Basket::pasteNote(TQClipboard::Mode mode)
}
closeEditor();
unselectAll();
- Note *note = NoteFactory::dropNote(KApplication::tqclipboard()->data(mode), this);
+ Note *note = NoteFactory::dropNote(KApplication::clipboard()->data(mode), this);
if (note) {
insertCreatedNote(note);
//unselectAllBut(note);
@@ -2764,7 +2764,7 @@ void Basket::drawInserter(TQPainter &painter, int xPainter, int yPainter)
int lineY = (m_inserterGroup && m_inserterTop ? 0 : 2);
int roundY = (m_inserterGroup && m_inserterTop ? 0 : 1);
- TQColor dark = KApplication::tqpalette().active().dark();
+ TQColor dark = KApplication::palette().active().dark();
TQColor light = dark.light().light();
if (m_inserterGroup && Settings::groupOnInsertionLine())
light = Tools::mixColor(light, KGlobalSettings::highlightColor());
@@ -3070,12 +3070,12 @@ void Basket::drawContents(TQPainter *painter, int clipX, int clipY, int clipWidt
m_decryptBox->setFrameShadow( TQFrame::Plain );
m_decryptBox->setLineWidth( 1 );
- TQGridLayout* tqlayout = new TQGridLayout( m_decryptBox, 1, 1, 11, 6, "decryptBoxLayout");
+ TQGridLayout* layout = new TQGridLayout( m_decryptBox, 1, 1, 11, 6, "decryptBoxLayout");
#ifdef HAVE_LIBGPGME
m_button = new TQPushButton( m_decryptBox, "button" );
m_button->setText( i18n( "&Unlock" ) );
- tqlayout->addWidget( m_button, 1, 2 );
+ layout->addWidget( m_button, 1, 2 );
connect( m_button, TQT_SIGNAL( clicked() ), this, TQT_SLOT( unlock() ) );
#endif
TQLabel* label = new TQLabel( m_decryptBox, "label" );
@@ -3086,13 +3086,13 @@ void Basket::drawContents(TQPainter *painter, int clipX, int clipY, int clipWidt
label->setText( text + i18n("Encryption is not supported by<br/>this version of %1.").arg(kapp->aboutData()->programName()) );
#endif
label->setAlignment( int( TQLabel::AlignTop ) );
- tqlayout->addMultiCellWidget( label, 0, 0, 1, 2 );
+ layout->addMultiCellWidget( label, 0, 0, 1, 2 );
TQLabel* pixmap = new TQLabel( m_decryptBox, "pixmap" );
pixmap->setPixmap( KGlobal::iconLoader()->loadIcon("encrypted", KIcon::NoGroup, KIcon::SizeHuge) );
- tqlayout->addMultiCellWidget( pixmap, 0, 1, 0, 0 );
+ layout->addMultiCellWidget( pixmap, 0, 1, 0, 0 );
TQSpacerItem* spacer = new TQSpacerItem( 40, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
- tqlayout->addItem( spacer, 1, 1 );
+ layout->addItem( spacer, 1, 1 );
label = new TQLabel("<small>" +
i18n("To make baskets stay unlocked, change the automatic<br>"
@@ -3100,9 +3100,9 @@ void Basket::drawContents(TQPainter *painter, int clipX, int clipY, int clipWidt
m_decryptBox);
//label->setFixedWidth(label->sizeHint().width() / 2);
label->setAlignment( int( TQLabel::AlignTop ) );
- tqlayout->addMultiCellWidget( label, 2,2,0,2 );
+ layout->addMultiCellWidget( label, 2,2,0,2 );
- m_decryptBox->resize(tqlayout->sizeHint());
+ m_decryptBox->resize(layout->sizeHint());
}
if(m_decryptBox->isHidden())
{
@@ -3420,7 +3420,7 @@ void Basket::toggledStateInMenu(int id)
if (id == 1) {
removeTagFromSelectedNotes(m_tagPopup);
//m_tagPopupNote->removeTag(m_tagPopup);
- //m_tagPopupNote->setWidth(0); // To force a new tqlayout computation
+ //m_tagPopupNote->setWidth(0); // To force a new layout computation
updateEditorAppearance();
filterAgain();
save();
@@ -3565,7 +3565,7 @@ void Basket::toggledTagInMenu(int id)
removeTagFromSelectedNotes(tag);
else
addTagToSelectedNotes(tag);
- m_tagPopupNote->setWidth(0); // To force a new tqlayout computation
+ m_tagPopupNote->setWidth(0); // To force a new layout computation
filterAgain();
save();
}
@@ -4196,7 +4196,7 @@ void Basket::noteDeleteWithoutConfirmation(bool deleteFilesToo)
void Basket::doCopy(CopyMode copyMode)
{
- TQClipboard *cb = KApplication::tqclipboard();
+ TQClipboard *cb = KApplication::clipboard();
TQClipboard::Mode mode = (copyMode == CopyToSelection ? TQClipboard::Selection : TQClipboard::Clipboard);
NoteSelection *selection = selectedNotes();
@@ -5047,7 +5047,7 @@ void Basket::selectRange(Note *start, Note *end, bool unselectOthers /*= true*/)
return;
}
- // Free tqlayout baskets should select range as if we were drawing a rectangle between start and end:
+ // Free layout baskets should select range as if we were drawing a rectangle between start and end:
if (isFreeLayout()) {
TQRect startRect( start->finalX(), start->finalY(), start->width(), start->finalHeight() );
TQRect endRect( end->finalX(), end->finalY(), end->width(), end->finalHeight() );
@@ -5439,15 +5439,15 @@ DiskErrorDialog::DiskErrorDialog(const TQString &titleMessage, const TQString &m
//enableButton(Close, false);
//enableButtonOK(false);
setModal(true);
- TQHBoxLayout *tqlayout = new TQHBoxLayout(plainPage(), /*margin=*/0, spacingHint());
+ TQHBoxLayout *layout = new TQHBoxLayout(plainPage(), /*margin=*/0, spacingHint());
TQPixmap icon = kapp->iconLoader()->loadIcon("hdd_unmount", KIcon::NoGroup, 64, KIcon::DefaultState, /*path_store=*/0L, /*canReturnNull=*/true);
TQLabel *iconLabel = new TQLabel(plainPage());
iconLabel->setPixmap(icon);
iconLabel->setFixedSize(iconLabel->sizeHint());
TQLabel *label = new TQLabel("<p><nobr><b><font size='+1'>" + titleMessage + "</font></b></nobr></p><p>" + message + "</p>", plainPage());
if (!icon.isNull())
- tqlayout->addWidget(iconLabel);
- tqlayout->addWidget(label);
+ layout->addWidget(iconLabel);
+ layout->addWidget(label);
}
DiskErrorDialog::~DiskErrorDialog()
diff --git a/src/basketproperties.cpp b/src/basketproperties.cpp
index 975e312..2ab6f42 100644
--- a/src/basketproperties.cpp
+++ b/src/basketproperties.cpp
@@ -99,7 +99,7 @@ BasketPropertiesDialog::BasketPropertiesDialog(Basket *basket, TQWidget *parent)
}
}
// m_backgroundImage->insertItem(i18n("Other..."), -1);
- int BUTTON_MARGIN = kapp->tqstyle().pixelMetric(TQStyle::PM_ButtonMargin);
+ int BUTTON_MARGIN = kapp->style().pixelMetric(TQStyle::PM_ButtonMargin);
m_backgroundImage->setSizeLimit(50/*75 * 6 / m_backgroundImage->sizeHint().height()*/);
m_backgroundImage->setMinimumHeight(75 + 2 * BUTTON_MARGIN);
diff --git a/src/debugwindow.cpp b/src/debugwindow.cpp
index e86ff99..5f1b80a 100644
--- a/src/debugwindow.cpp
+++ b/src/debugwindow.cpp
@@ -33,19 +33,19 @@ DebugWindow::DebugWindow(TQWidget *parent, const char *name )
Global::debugWindow = this;
setCaption(i18n("Debug Window"));
- tqlayout = new TQVBoxLayout(this);
+ layout = new TQVBoxLayout(this);
textBrowser = new TQTextBrowser(this);
textBrowser->setWordWrap(TQTextBrowser::NoWrap);
- tqlayout->addWidget(textBrowser);
+ layout->addWidget(textBrowser);
textBrowser->show();
}
DebugWindow::~DebugWindow()
{
delete textBrowser;
- delete tqlayout;
+ delete layout;
}
void DebugWindow::postMessage(const TQString msg)
diff --git a/src/debugwindow.h b/src/debugwindow.h
index 5a72790..31b9911 100644
--- a/src/debugwindow.h
+++ b/src/debugwindow.h
@@ -46,7 +46,7 @@ class DebugWindow : public TQWidget {
protected:
virtual void closeEvent(TQCloseEvent *event);
private:
- TQVBoxLayout *tqlayout;
+ TQVBoxLayout *layout;
TQTextBrowser *textBrowser;
};
diff --git a/src/focusedwidgets.cpp b/src/focusedwidgets.cpp
index ac46eec..d472555 100644
--- a/src/focusedwidgets.cpp
+++ b/src/focusedwidgets.cpp
@@ -67,7 +67,7 @@ void FocusedTextEdit::paste()
// uint oldAutoFormating = autoFormatting();
// setAutoFormatting(AutoNone);
- TQClipboard *clipboard = TQApplication::tqclipboard();
+ TQClipboard *clipboard = TQApplication::clipboard();
int paragraph;
int index;
getCursorPosition(&paragraph, &index);
@@ -107,7 +107,7 @@ void FocusedTextEdit::paste()
*/
void FocusedTextEdit::adaptClipboardText(TQClipboard::Mode mode)
{
- TQClipboard *clipboard = TQApplication::tqclipboard();
+ TQClipboard *clipboard = TQApplication::clipboard();
if (!clipboard)
return;
diff --git a/src/kcolorcombo2.h b/src/kcolorcombo2.h
index b76f538..1862051 100644
--- a/src/kcolorcombo2.h
+++ b/src/kcolorcombo2.h
@@ -316,7 +316,7 @@ class KColorPopup : public TQWidget
public:
KColorPopup(KColorCombo2 *parent);
~KColorPopup();
- void retqlayout(); // updateGeometry() ??
+ void relayout(); // updateGeometry() ??
protected:
void paintEvent(TQPaintEvent */*event*/);
void mouseMoveEvent(TQMouseEvent *event);
diff --git a/src/kicondialog.cpp b/src/kicondialog.cpp
index 0122289..295fdb4 100644
--- a/src/kicondialog.cpp
+++ b/src/kicondialog.cpp
@@ -256,7 +256,7 @@ void KIconDialog::setup(KIcon::Group group, KIcon::Context context,
d->extendedContext = static_cast<ExtendedContext>( ( context == KIcon::Any ) ? ALL : context + 1 );
- // We cannot change tqlayout because it is protected ;-(
+ // We cannot change layout because it is protected ;-(
// FIXME: TQt4 we will be able to inherit from both TQDialog and our GUI
d->ui->listBox->setEnabled(!lockContext);
d->ui->browseButton->setEnabled(!lockBrowse);
diff --git a/src/kicondialogui.ui b/src/kicondialogui.ui
index 0632f49..d3febc8 100644
--- a/src/kicondialogui.ui
+++ b/src/kicondialogui.ui
@@ -72,7 +72,7 @@
</widget>
<widget class="TQLayoutWidget" row="1" column="1">
<property name="name">
- <cstring>tqlayout4</cstring>
+ <cstring>layout4</cstring>
</property>
<vbox>
<property name="name">
@@ -83,7 +83,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
diff --git a/src/likeback.cpp b/src/likeback.cpp
index ebae729..75a51d6 100644
--- a/src/likeback.cpp
+++ b/src/likeback.cpp
@@ -62,7 +62,7 @@ LikeBackBar::LikeBackBar(LikeBack *likeBack)
: TQWidget(0, "LikeBackBar", TQt::WX11BypassWM | TQt::WStyle_NoBorder | TQt::WNoAutoErase | TQt::WStyle_StaysOnTop | TQt::WStyle_NoBorder | TQt::TQt::WGroupLeader)
, m_likeBack(likeBack)
{
- TQHBoxLayout *tqlayout = new TQHBoxLayout(this);
+ TQHBoxLayout *layout = new TQHBoxLayout(this);
TQIconSet likeIconSet = kapp->iconLoader()->loadIconSet("likeback_like", KIcon::Small);
TQIconSet dislikeIconSet = kapp->iconLoader()->loadIconSet("likeback_dislike", KIcon::Small);
@@ -74,28 +74,28 @@ LikeBackBar::LikeBackBar(LikeBack *likeBack)
m_likeButton->setTextLabel("<p>" + i18n("Send application developers a comment about something you like"));
m_likeButton->setAutoRaise(true);
connect( m_likeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickedLike()) );
- tqlayout->add(m_likeButton);
+ layout->add(m_likeButton);
m_dislikeButton = new TQToolButton(this, "likeback_dislike");
m_dislikeButton->setIconSet(dislikeIconSet);
m_dislikeButton->setTextLabel("<p>" + i18n("Send application developers a comment about something you dislike"));
m_dislikeButton->setAutoRaise(true);
connect( m_dislikeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickedDislike()) );
- tqlayout->add(m_dislikeButton);
+ layout->add(m_dislikeButton);
m_bugButton = new TQToolButton(this, "likeback_bug");
m_bugButton->setIconSet(bugIconSet);
m_bugButton->setTextLabel("<p>" + i18n("Send application developers a comment about an improper behavior of the application"));
m_bugButton->setAutoRaise(true);
connect( m_bugButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickedBug()) );
- tqlayout->add(m_bugButton);
+ layout->add(m_bugButton);
m_featureButton = new TQToolButton(this, "likeback_feature");
m_featureButton->setIconSet(featureIconSet);
m_featureButton->setTextLabel("<p>" + i18n("Send application developers a comment about a new feature you desire"));
m_featureButton->setAutoRaise(true);
connect( m_featureButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickedFeature()) );
- tqlayout->add(m_featureButton);
+ layout->add(m_featureButton);
connect( &m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(autoMove()) );
diff --git a/src/linklabel.cpp b/src/linklabel.cpp
index 77d5cd2..6932dca 100644
--- a/src/linklabel.cpp
+++ b/src/linklabel.cpp
@@ -392,7 +392,7 @@ void LinkDisplay::setLink(const TQString &title, const TQString &icon, const TQP
m_font = font;
// "Constants":
- int BUTTON_MARGIN = kapp->tqstyle().pixelMetric(TQStyle::PM_ButtonMargin);
+ int BUTTON_MARGIN = kapp->style().pixelMetric(TQStyle::PM_ButtonMargin);
int LINK_MARGIN = BUTTON_MARGIN + 2;
// Recompute m_minWidth:
@@ -430,7 +430,7 @@ void LinkDisplay::setWidth(int width)
void LinkDisplay::paint(TQPainter *painter, int x, int y, int width, int height, const TQColorGroup &colorGroup,
bool isDefaultColor, bool isSelected, bool isHovered, bool isIconButtonHovered) const
{
- int BUTTON_MARGIN = kapp->tqstyle().pixelMetric(TQStyle::PM_ButtonMargin);
+ int BUTTON_MARGIN = kapp->style().pixelMetric(TQStyle::PM_ButtonMargin);
int LINK_MARGIN = BUTTON_MARGIN + 2;
TQPixmap pixmap;
@@ -449,7 +449,7 @@ void LinkDisplay::paint(TQPainter *painter, int x, int y, int width, int height,
int pixmapY = (height - pixmap.height()) / 2;
// Draw the button (if any) and the icon:
if (isHovered)
- kapp->tqstyle().tqdrawPrimitive(TQStyle::PE_ButtonCommand, painter, TQRect(-1, -1, iconPreviewWidth + 2*BUTTON_MARGIN, height + 2),
+ kapp->style().tqdrawPrimitive(TQStyle::PE_ButtonCommand, painter, TQRect(-1, -1, iconPreviewWidth + 2*BUTTON_MARGIN, height + 2),
colorGroup, TQStyle::Style_Enabled | (isIconButtonHovered ? TQStyle::Style_MouseOver : 0));
painter->drawPixmap(x + BUTTON_MARGIN - 1 + pixmapX, y + pixmapY, pixmap);
@@ -483,7 +483,7 @@ TQPixmap LinkDisplay::feedbackPixmap(int width, int height, const TQColorGroup &
bool LinkDisplay::iconButtonAt(const TQPoint &pos) const
{
- int BUTTON_MARGIN = kapp->tqstyle().pixelMetric(TQStyle::PM_ButtonMargin);
+ int BUTTON_MARGIN = kapp->style().pixelMetric(TQStyle::PM_ButtonMargin);
// int LINK_MARGIN = BUTTON_MARGIN + 2;
int iconPreviewWidth = TQMAX(m_look->iconSize(), (m_look->previewEnabled() ? m_preview.width() : 0));
@@ -492,7 +492,7 @@ bool LinkDisplay::iconButtonAt(const TQPoint &pos) const
TQRect LinkDisplay::iconButtonRect() const
{
- int BUTTON_MARGIN = kapp->tqstyle().pixelMetric(TQStyle::PM_ButtonMargin);
+ int BUTTON_MARGIN = kapp->style().pixelMetric(TQStyle::PM_ButtonMargin);
// int LINK_MARGIN = BUTTON_MARGIN + 2;
int iconPreviewWidth = TQMAX(m_look->iconSize(), (m_look->previewEnabled() ? m_preview.width() : 0));
@@ -517,7 +517,7 @@ TQFont LinkDisplay::labelFont(TQFont font, bool isIconButtonHovered) const
int LinkDisplay::heightForWidth(int width) const
{
- int BUTTON_MARGIN = kapp->tqstyle().pixelMetric(TQStyle::PM_ButtonMargin);
+ int BUTTON_MARGIN = kapp->style().pixelMetric(TQStyle::PM_ButtonMargin);
int LINK_MARGIN = BUTTON_MARGIN + 2;
int iconPreviewWidth = TQMAX(m_look->iconSize(), (m_look->previewEnabled() ? m_preview.width() : 0));
int iconPreviewHeight = TQMAX(m_look->iconSize(), (m_look->previewEnabled() ? m_preview.height() : 0));
@@ -559,15 +559,15 @@ LinkLookEditWidget::LinkLookEditWidget(KCModule *module, const TQString exTitle,
: TQWidget(parent, name, fl)
{
TQLabel *label;
- TQVBoxLayout *tqlayout = new TQVBoxLayout(this, KDialogBase::marginHint(), KDialogBase::spacingHint());
+ TQVBoxLayout *layout = new TQVBoxLayout(this, KDialogBase::marginHint(), KDialogBase::spacingHint());
m_italic = new TQCheckBox(i18n("I&talic"), this);
- tqlayout->addWidget(m_italic);
+ layout->addWidget(m_italic);
m_bold = new TQCheckBox(i18n("&Bold"), this);
- tqlayout->addWidget(m_bold);
+ layout->addWidget(m_bold);
- TQGridLayout *gl = new TQGridLayout(tqlayout, /*rows=*//*(look->canPreview() ? 5 : 4)*/5, /*columns=*//*3*/4);
+ TQGridLayout *gl = new TQGridLayout(layout, /*rows=*//*(look->canPreview() ? 5 : 4)*/5, /*columns=*//*3*/4);
gl->addItem(new TQSpacerItem(0, 0, TQSizePolicy::Expanding), 1, /*2*/3);
m_underlining = new TQComboBox(false, this);
@@ -625,7 +625,7 @@ LinkLookEditWidget::LinkLookEditWidget(KCModule *module, const TQString exTitle,
m_example = new LinkLabel(exTitle, exIcon, m_exLook, 1, 1, gb);
m_example->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
m_example->setCursor(TQCursor(TQt::PointingHandCursor));
- tqlayout->addWidget(gb);
+ layout->addWidget(gb);
m_exTitle = exTitle;
m_exIcon = exIcon;
diff --git a/src/newbasketdialog.cpp b/src/newbasketdialog.cpp
index 04d39a8..c782583 100644
--- a/src/newbasketdialog.cpp
+++ b/src/newbasketdialog.cpp
@@ -116,7 +116,7 @@ NewBasketDialog::NewBasketDialog(Basket *parentBasket, const NewBasketDefaultPro
nameLayout->addWidget(m_backgroundColor);
topLayout->addLayout(nameLayout);
- TQHBoxLayout *tqlayout = new TQHBoxLayout(/*parent=*/0, /*margin=*/0, spacingHint());
+ TQHBoxLayout *layout = new TQHBoxLayout(/*parent=*/0, /*margin=*/0, spacingHint());
KPushButton *button = new KPushButton( KGuiItem(i18n("&Manage Templates..."), "configure"), page );
connect( button, TQT_SIGNAL(clicked()), this, TQT_SLOT(manageTemplates()) );
button->hide();
@@ -203,13 +203,13 @@ NewBasketDialog::NewBasketDialog(Basket *parentBasket, const NewBasketDefaultPro
m_templates->setMinimumHeight(topLayout->minimumSize().width() * 9 / 16);
TQLabel *label = new TQLabel(m_templates, i18n("&Template:"), page);
- tqlayout->addWidget(label, /*stretch=*/0, TQt::AlignBottom);
- tqlayout->addStretch();
- tqlayout->addWidget(button, /*stretch=*/0, TQt::AlignBottom);
- topLayout->addLayout(tqlayout);
+ layout->addWidget(label, /*stretch=*/0, TQt::AlignBottom);
+ layout->addStretch();
+ layout->addWidget(button, /*stretch=*/0, TQt::AlignBottom);
+ topLayout->addLayout(layout);
topLayout->addWidget(m_templates);
- tqlayout = new TQHBoxLayout(/*parent=*/0, /*margin=*/0, spacingHint());
+ layout = new TQHBoxLayout(/*parent=*/0, /*margin=*/0, spacingHint());
m_createIn = new TQComboBox(page);
m_createIn->insertItem(i18n("(Baskets)"));
label = new TQLabel(m_createIn, i18n("C&reate in:"), page);
@@ -219,11 +219,11 @@ NewBasketDialog::NewBasketDialog(Basket *parentBasket, const NewBasketDefaultPro
"<li>Grouping baskets in folders for different projects;</li>"
"<li>Making sections with sub-baskets representing chapters or pages;</li>"
"<li>Making a group of baskets to export together (to eg. email them to people).</li></ul>"), page);
- tqlayout->addWidget(label);
- tqlayout->addWidget(m_createIn);
- tqlayout->addWidget(helpLabel);
- tqlayout->addStretch();
- topLayout->addLayout(tqlayout);
+ layout->addWidget(label);
+ layout->addWidget(m_createIn);
+ layout->addWidget(helpLabel);
+ layout->addStretch();
+ topLayout->addLayout(layout);
m_basketsMap.clear();
m_basketsMap.insert(/*index=*/0, /*basket=*/0L);
diff --git a/src/note.cpp b/src/note.cpp
index 436441d..adf859d 100644
--- a/src/note.cpp
+++ b/src/note.cpp
@@ -853,20 +853,20 @@ void Note::unsetWidth()
child->unsetWidth();
}
-void Note::requestRetqlayout()
+void Note::requestRelayout()
{
m_width = 0;
unbufferize();
- basket()->relayoutNotes(true); // TODO: A signal that will retqlayout ONCE and DELAYED if called several times
+ basket()->relayoutNotes(true); // TODO: A signal that will relayout ONCE and DELAYED if called several times
}
void Note::setWidth(int width) // TODO: inline ?
{
if (m_width != width)
- setWidthForceRetqlayout(width);
+ setWidthForceRelayout(width);
}
-void Note::setWidthForceRetqlayout(int width)
+void Note::setWidthForceRelayout(int width)
{
unbufferize();
m_width = (width < minWidth() ? minWidth() : width);
@@ -970,7 +970,7 @@ void Note::toggleFolded(bool animate)
if (animate) {
// We animate collapsing (so sub-notes fluidly go under the first note)
- // We don't animate expanding: we place sub-notes directly under the first note (and the next retqlayout will animate the expanding)
+ // We don't animate expanding: we place sub-notes directly under the first note (and the next relayout will animate the expanding)
// But if user quickly collapsed and then expand (while the collapsing animation isn't finished), we animate anyway
bool animateSetUnder = (m_isFolded || !m_collapseFinished);
// std::cout << "fold:" << m_isFolded << " collapseFinished:" << m_collapseFinished << " animateSetUnder:" << animateSetUnder << std::endl;
@@ -1098,7 +1098,7 @@ void Note::relayoutAt(int x, int y, bool animate)
m_computedAreas = false;
m_areas.clear();
- // Don't retqlayout free notes one under the other, because by definition they are freely positionned!
+ // Don't relayout free notes one under the other, because by definition they are freely positionned!
if (isFree()) {
x = finalX();
y = finalY();
@@ -1109,7 +1109,7 @@ void Note::relayoutAt(int x, int y, bool animate)
cancelAnimation();
setX(x);
setY(y);
- // But retqlayout others vertically if they are inside such primary groups or if it is a "normal" basket:
+ // But relayout others vertically if they are inside such primary groups or if it is a "normal" basket:
} else {
if (animate)
setFinalPosition(x, y);
@@ -1120,13 +1120,13 @@ void Note::relayoutAt(int x, int y, bool animate)
}
}
- // Then, retqlayout sub-notes (only the first, if the group is folded) and so, assign an height to the group:
+ // Then, relayout sub-notes (only the first, if the group is folded) and so, assign an height to the group:
if (isGroup()) {
int h = 0;
Note *child = firstChild();
bool first = true;
while (child) {
- if (child->matching() && (!m_isFolded || first || basket()->isFiltering())) { // Don't use showSubNotes() but use !m_isFolded because we don't want a retqlayout for the animated collapsing notes
+ if (child->matching() && (!m_isFolded || first || basket()->isFiltering())) { // Don't use showSubNotes() but use !m_isFolded because we don't want a relayout for the animated collapsing notes
child->relayoutAt(x + width(), y+h, animate);
h += child->finalHeight();
} else // In case the user collapse a group, then move it and then expand it:
@@ -1282,7 +1282,7 @@ void drawGradient( TQPainter *p, const TQColor &colorTop, const TQColor & colorB
void Note::drawExpander(TQPainter *painter, int x, int y, const TQColor &background, bool expand, Basket *basket)
{
// If the current style is a KStyle, use it to draw the expander (plus or minus):
- if (dynamic_cast<KStyle*>(&(kapp->tqstyle())) != NULL) {
+ if (dynamic_cast<KStyle*>(&(kapp->style())) != NULL) {
// Set the 4 rounded corners background to background color:
TQColorGroup cg(basket->colorGroup());
cg.setColor(TQColorGroup::Base, background);
@@ -1292,7 +1292,7 @@ void Note::drawExpander(TQPainter *painter, int x, int y, const TQColor &backgro
painter->fillRect(x, y, 9, 9, brush);
// Draw it:
- ((KStyle&)(kapp->tqstyle())).drawKStylePrimitive( KStyle::KPE_ListViewExpander,
+ ((KStyle&)(kapp->style())).drawKStylePrimitive( KStyle::KPE_ListViewExpander,
painter,
basket->viewport(),
TQRect(x, y, 9, 9),
@@ -2146,7 +2146,7 @@ void Note::recomputeStyle()
// unsetWidth();
if (content())
content()->fontChanged();
-// requestRetqlayout(); // TODO!
+// requestRelayout(); // TODO!
}
void Note::recomputeAllStyles()
diff --git a/src/note.h b/src/note.h
index 453258d..a26f903 100644
--- a/src/note.h
+++ b/src/note.h
@@ -74,7 +74,7 @@ class Note
// int m_minContentWidth;
public:
void setWidth(int width);
- void setWidthForceRetqlayout(int width);
+ void setWidthForceRelayout(int width);
void setInitialHeight(int height) { m_height = height; } /// << Do NEVER use it unless you know what you do!
void setX(int x);
void setY(int y);
@@ -93,7 +93,7 @@ class Note
int minWidth();
int minRight();
void unsetWidth();
- void requestRetqlayout();
+ void requestRelayout();
void setHeight(int height) { m_height = height; } /// << DO NEVER USE IT!!! Only available when moving notes, groups should be recreated with the exact same state as before!
/// FREE AND COLUMN LAYOUTS MANAGEMENT:
diff --git a/src/notecontent.h b/src/notecontent.h
index bc71876..52bd636 100644
--- a/src/notecontent.h
+++ b/src/notecontent.h
@@ -82,7 +82,7 @@ class NoteContent // TODO: Mark some methods as const! and some (lik
// Complexe Abstract Generic Methods:
virtual void exportToHTML(HTMLExporter *exporter, int indent) = 0; /// << Export the note in an HTML file.
virtual TQString cssClass() = 0; /// << @return the CSS class of the note when exported to HTML
- virtual int setWidthAndGetHeight(int width) = 0; /// << Retqlayout content with @p width (never less than minWidth()). @return its new height.
+ virtual int setWidthAndGetHeight(int width) = 0; /// << Relayout content with @p width (never less than minWidth()). @return its new height.
virtual void paint(TQPainter *painter, int width, int height, const TQColorGroup &colorGroup, bool isDefaultColor, bool isSelected, bool isHovered) = 0; /// << Paint the content on @p painter, at coordinate (0, 0) and with the size (@p width, @p height).
virtual bool loadFromFile(bool /*lazyLoad*/) { return false; } /// << Load the content from the file. The default implementation does nothing. @see fileName().
virtual bool finishLazyLoad() { return false; } /// << Load what was not loaded by loadFromFile() if it was lazy-loaded
@@ -131,7 +131,7 @@ class NoteContent // TODO: Mark some methods as const! and some (lik
public:
void setEdited(); /// << Mark the note as edited NOW: change the "last modification time and time" AND save the basket to XML file.
protected:
- void contentChanged(int newMinWidth); /// << When the content has changed, inherited classes should call this to specify its new minimum size and trigger a basket retqlayout.
+ void contentChanged(int newMinWidth); /// << When the content has changed, inherited classes should call this to specify its new minimum size and trigger a basket relayout.
private:
Note *m_note;
TQString m_fileName;
@@ -176,7 +176,7 @@ class TextContent : public NoteContent
TQString messageWhenOpenning(OpenMessage where);
// TQString customOpenCommand();
// Content-Specific Methods:
- void setText(const TQString &text, bool lazyLoad = false); /// << Change the text note-content and retqlayout the note.
+ void setText(const TQString &text, bool lazyLoad = false); /// << Change the text note-content and relayout the note.
TQString text() { return m_text; } /// << @return the text note-content.
protected:
TQString m_text;
@@ -219,7 +219,7 @@ class HtmlContent : public NoteContent
TQString messageWhenOpenning(OpenMessage where);
TQString customOpenCommand();
// Content-Specific Methods:
- void setHtml(const TQString &html, bool lazyLoad = false); /// << Change the HTML note-content and retqlayout the note.
+ void setHtml(const TQString &html, bool lazyLoad = false); /// << Change the HTML note-content and relayout the note.
TQString html() { return m_html; } /// << @return the HTML note-content.
protected:
TQString m_html;
@@ -263,7 +263,7 @@ class ImageContent : public NoteContent
TQString messageWhenOpenning(OpenMessage where);
TQString customOpenCommand();
// Content-Specific Methods:
- void setPixmap(const TQPixmap &pixmap); /// << Change the pixmap note-content and retqlayout the note.
+ void setPixmap(const TQPixmap &pixmap); /// << Change the pixmap note-content and relayout the note.
TQPixmap pixmap() { return m_pixmap; } /// << @return the pixmap note-content.
protected:
TQPixmap m_pixmap;
@@ -307,7 +307,7 @@ class AnimationContent : public TQObject, public NoteContent // TQObject to be a
TQString messageWhenOpenning(OpenMessage where);
TQString customOpenCommand();
// Content-Specific Methods:
- bool setMovie(const TQMovie &movie); /// << Change the movie note-content and retqlayout the note.
+ bool setMovie(const TQMovie &movie); /// << Change the movie note-content and relayout the note.
TQMovie movie() { return m_movie; } /// << @return the movie note-content.
protected slots:
void movieUpdated(const TQRect&);
@@ -360,7 +360,7 @@ class FileContent : public TQObject, public NoteContent
// Open Content or File:
TQString messageWhenOpenning(OpenMessage where);
// Content-Specific Methods:
- void setFileName(const TQString &fileName); /// << Reimplemented to be able to retqlayout the note.
+ void setFileName(const TQString &fileName); /// << Reimplemented to be able to relayout the note.
virtual LinkLook* linkLook() { return LinkLook::fileLook; }
protected:
LinkDisplay m_linkDisplay;
@@ -449,7 +449,7 @@ class LinkContent : public TQObject, public NoteContent
KURL urlToOpen(bool /*with*/);
TQString messageWhenOpenning(OpenMessage where);
// Content-Specific Methods:
- void setLink(const KURL &url, const TQString &title, const TQString &icon, bool autoTitle, bool autoIcon); /// << Change the link and retqlayout the note.
+ void setLink(const KURL &url, const TQString &title, const TQString &icon, bool autoTitle, bool autoIcon); /// << Change the link and relayout the note.
KURL url() { return m_url; } /// << @return the URL of the link note-content.
TQString title() { return m_title; } /// << @return the displayed title of the link note-content.
TQString icon() { return m_icon; } /// << @return the displayed icon of the link note-content.
@@ -509,7 +509,7 @@ class LauncherContent : public NoteContent
KURL urlToOpen(bool with);
TQString messageWhenOpenning(OpenMessage where);
// Content-Specific Methods:
- void setLauncher(const TQString &name, const TQString &icon, const TQString &exec); /// << Change the launcher note-content and retqlayout the note. Normally called by loadFromFile (no save done).
+ void setLauncher(const TQString &name, const TQString &icon, const TQString &exec); /// << Change the launcher note-content and relayout the note. Normally called by loadFromFile (no save done).
TQString name() { return m_name; } /// << @return the URL of the launcher note-content.
TQString icon() { return m_icon; } /// << @return the displayed icon of the launcher note-content.
TQString exec() { return m_exec; } /// << @return the execute command line of the launcher note-content.
@@ -554,7 +554,7 @@ class ColorContent : public NoteContent
bool needSpaceForFeedbackPixmap() { return true; }
void addAlternateDragObjects(KMultipleDrag *dragObject);
// Content-Specific Methods:
- void setColor(const TQColor &color); /// << Change the color note-content and retqlayout the note.
+ void setColor(const TQColor &color); /// << Change the color note-content and relayout the note.
TQColor color() { return m_color; } /// << @return the color note-content.
protected:
TQColor m_color;
diff --git a/src/notedrag.cpp b/src/notedrag.cpp
index 67b45a3..3b4ad3d 100644
--- a/src/notedrag.cpp
+++ b/src/notedrag.cpp
@@ -571,8 +571,8 @@ bool ExtendedTextDrag::decode(const TQMimeSource *e, TQString &str, TQCString &s
str = TQTextCodec::codecForName("utf8")->toUnicode(utf8);
return true;
}
- if (e->provides("text/tqunicode")) { // FIXME: It's UTF-16 without order bytes!!!
- TQByteArray utf16 = e->encodedData("text/tqunicode");
+ if (e->provides("text/unicode")) { // FIXME: It's UTF-16 without order bytes!!!
+ TQByteArray utf16 = e->encodedData("text/unicode");
str = TQTextCodec::codecForName("utf16")->toUnicode(utf16);
return true;
}
diff --git a/src/noteedit.cpp b/src/noteedit.cpp
index bdebdb5..0edda4d 100644
--- a/src/noteedit.cpp
+++ b/src/noteedit.cpp
@@ -536,7 +536,7 @@ LinkEditDialog::LinkEditDialog(LinkContent *contentNote, TQWidget *parent/*, TQK
m_noteContent(contentNote)
{
TQWidget *page = plainPage();
- TQGridLayout *tqlayout = new TQGridLayout(page, /*nRows=*/4, /*nCols=*/2, /*margin=*/0, spacingHint());
+ TQGridLayout *layout = new TQGridLayout(page, /*nRows=*/4, /*nCols=*/2, /*margin=*/0, spacingHint());
m_url = new KURLRequester(m_noteContent->url().url(), page);
@@ -578,12 +578,12 @@ LinkEditDialog::LinkEditDialog(LinkContent *contentNote, TQWidget *parent/*, TQK
//m_url->setShowLocalProtocol(true);
TQLabel *label1 = new TQLabel(m_url, i18n("Ta&rget:"), page);
TQLabel *label2 = new TQLabel(m_title, i18n("&Title:"), page);
- tqlayout->addWidget(label1, 0, 0, TQt::AlignVCenter);
- tqlayout->addWidget(label2, 1, 0, TQt::AlignVCenter);
- tqlayout->addWidget(label3, 2, 0, TQt::AlignVCenter);
- tqlayout->addWidget(m_url, 0, 1, TQt::AlignVCenter);
- tqlayout->addWidget(wid1, 1, 1, TQt::AlignVCenter);
- tqlayout->addWidget(wid, 2, 1, TQt::AlignVCenter);
+ layout->addWidget(label1, 0, 0, TQt::AlignVCenter);
+ layout->addWidget(label2, 1, 0, TQt::AlignVCenter);
+ layout->addWidget(label3, 2, 0, TQt::AlignVCenter);
+ layout->addWidget(m_url, 0, 1, TQt::AlignVCenter);
+ layout->addWidget(wid1, 1, 1, TQt::AlignVCenter);
+ layout->addWidget(wid, 2, 1, TQt::AlignVCenter);
m_isAutoModified = false;
connect( m_url, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(urlChanged(const TQString&)) );
@@ -594,7 +594,7 @@ LinkEditDialog::LinkEditDialog(LinkContent *contentNote, TQWidget *parent/*, TQK
TQWidget *stretchWidget = new TQWidget(page);
stretchWidget->setSizePolicy(TQSizePolicy(/*hor=*/TQSizePolicy::Fixed, /*ver=*/TQSizePolicy::Expanding, /*hStretch=*/1, /*vStretch=*/255)); // Make it fill ALL vertical space
- tqlayout->addWidget(stretchWidget, 3, 1, TQt::AlignVCenter);
+ layout->addWidget(stretchWidget, 3, 1, TQt::AlignVCenter);
urlChanged("");
@@ -695,7 +695,7 @@ LauncherEditDialog::LauncherEditDialog(LauncherContent *contentNote, TQWidget *p
m_noteContent(contentNote)
{
TQWidget *page = plainPage();
- TQGridLayout *tqlayout = new TQGridLayout(page, /*nRows=*/4, /*nCols=*/2, /*margin=*/0, spacingHint());
+ TQGridLayout *layout = new TQGridLayout(page, /*nRows=*/4, /*nCols=*/2, /*margin=*/0, spacingHint());
KService service(contentNote->fullPath());
@@ -726,16 +726,16 @@ LauncherEditDialog::LauncherEditDialog(LauncherContent *contentNote, TQWidget *p
TQLabel *label1 = new TQLabel(m_command->lineEdit(), i18n("Comman&d:"), page);
TQLabel *label2 = new TQLabel(m_name, i18n("&Name:"), page);
- tqlayout->addWidget(label1, 0, 0, TQt::AlignVCenter);
- tqlayout->addWidget(label2, 1, 0, TQt::AlignVCenter);
- tqlayout->addWidget(label, 2, 0, TQt::AlignVCenter);
- tqlayout->addWidget(m_command, 0, 1, TQt::AlignVCenter);
- tqlayout->addWidget(m_name, 1, 1, TQt::AlignVCenter);
- tqlayout->addWidget(wid, 2, 1, TQt::AlignVCenter);
+ layout->addWidget(label1, 0, 0, TQt::AlignVCenter);
+ layout->addWidget(label2, 1, 0, TQt::AlignVCenter);
+ layout->addWidget(label, 2, 0, TQt::AlignVCenter);
+ layout->addWidget(m_command, 0, 1, TQt::AlignVCenter);
+ layout->addWidget(m_name, 1, 1, TQt::AlignVCenter);
+ layout->addWidget(wid, 2, 1, TQt::AlignVCenter);
TQWidget *stretchWidget = new TQWidget(page);
stretchWidget->setSizePolicy(TQSizePolicy(/*hor=*/TQSizePolicy::Fixed, /*ver=*/TQSizePolicy::Expanding, /*hStretch=*/1, /*vStretch=*/255)); // Make it fill ALL vertical space
- tqlayout->addWidget(stretchWidget, 3, 1, TQt::AlignVCenter);
+ layout->addWidget(stretchWidget, 3, 1, TQt::AlignVCenter);
connect( guessButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(guessIcon()) );
}
diff --git a/src/password.cpp b/src/password.cpp
index 28862e0..b2f8abe 100644
--- a/src/password.cpp
+++ b/src/password.cpp
@@ -36,9 +36,9 @@ PasswordDlg::PasswordDlg(TQWidget *parent, const char *name)
:KDialogBase(Plain, i18n("Password Protection"), Ok|Cancel, Ok,
parent, name, /*modal=*/true, /*separator=*/true), w(0)
{
- TQHBoxLayout* toptqlayout = new TQHBoxLayout(plainPage(), 0, 0);
+ TQHBoxLayout* toplayout = new TQHBoxLayout(plainPage(), 0, 0);
w = new Password(plainPage());
- toptqlayout->addWidget(w, 1);
+ toplayout->addWidget(w, 1);
}
PasswordDlg::~PasswordDlg()
diff --git a/src/passwordlayout.ui b/src/passwordlayout.ui
index a26820c..d2c577c 100644
--- a/src/passwordlayout.ui
+++ b/src/passwordlayout.ui
@@ -60,7 +60,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
diff --git a/src/regiongrabber.cpp b/src/regiongrabber.cpp
index 4c4d9ca..3e14d71 100644
--- a/src/regiongrabber.cpp
+++ b/src/regiongrabber.cpp
@@ -171,7 +171,7 @@ void RegionGrabber::drawRubber()
p.setPen( TQPen( color0, 1 ) );
p.setBrush( NoBrush );
- tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, &p, grabRect, colorGroup(),
+ style().tqdrawPrimitive( TQStyle::PE_FocusRect, &p, grabRect, colorGroup(),
TQStyle::Style_Default, TQStyleOption( colorGroup().base() ) );
p.end();
diff --git a/src/settings.cpp b/src/settings.cpp
index 9195324..4c9d2f3 100644
--- a/src/settings.cpp
+++ b/src/settings.cpp
@@ -357,12 +357,12 @@ void Settings::setAutoBullet(bool yes)
GeneralPage::GeneralPage(TQWidget * parent, const char * name)
: KCModule(parent, name)
{
- TQVBoxLayout *tqlayout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
+ TQVBoxLayout *layout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
TQHBoxLayout *hLay;
TQLabel *label;
HelpLabel *hLabel;
- TQGridLayout *gl = new TQGridLayout(tqlayout, /*nRows=*/3, /*nCols=*/3);
+ TQGridLayout *gl = new TQGridLayout(layout, /*nRows=*/3, /*nCols=*/3);
gl->addItem(new TQSpacerItem(0, 0, TQSizePolicy::Expanding), 0, 2);
// Basket Tree Position:
@@ -399,11 +399,11 @@ GeneralPage::GeneralPage(TQWidget * parent, const char * name)
hLay->addWidget(m_usePassivePopup);
hLay->addWidget(hLabel);
hLay->addStretch();
- tqlayout->addLayout(hLay);
+ layout->addLayout(hLay);
// System Tray Icon:
TQGroupBox *gbSys = new TQGroupBox(3, Qt::Vertical, i18n("System Tray Icon"), this);
- tqlayout->addWidget(gbSys);
+ layout->addWidget(gbSys);
TQVBoxLayout *sysLay = new TQVBoxLayout(gbSys, /*margin=*/0, KDialogBase::spacingHint());
// Dock in System Tray:
@@ -450,7 +450,7 @@ GeneralPage::GeneralPage(TQWidget * parent, const char * name)
connect( m_useSystray, TQT_SIGNAL(toggled(bool)), m_systray, TQT_SLOT(setEnabled(bool)) );
- tqlayout->insertStretch(-1);
+ layout->insertStretch(-1);
load();
}
@@ -502,14 +502,14 @@ void GeneralPage::defaults()
BasketsPage::BasketsPage(TQWidget * parent, const char * name)
: KCModule(parent, name)
{
- TQVBoxLayout *tqlayout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
+ TQVBoxLayout *layout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
TQHBoxLayout *hLay;
HelpLabel *hLabel;
// Appearance:
TQGroupBox *appearanceBox = new TQGroupBox(3, Qt::Vertical, i18n("Appearance"), this);
- tqlayout->addWidget(appearanceBox);
+ layout->addWidget(appearanceBox);
m_playAnimations = new TQCheckBox(i18n("Ani&mate changes in baskets"), appearanceBox);
connect( m_playAnimations, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changed()) );
@@ -523,7 +523,7 @@ BasketsPage::BasketsPage(TQWidget * parent, const char * name)
// Behavior:
TQGroupBox *behaviorBox = new TQGroupBox(5, Qt::Vertical, i18n("Behavior"), this);
- tqlayout->addWidget(behaviorBox);
+ layout->addWidget(behaviorBox);
m_autoBullet = new TQCheckBox(i18n("&Transform lines starting with * or - to lists in text editors"), behaviorBox);
connect( m_autoBullet, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changed()) );
@@ -566,7 +566,7 @@ BasketsPage::BasketsPage(TQWidget * parent, const char * name)
hLayV->addWidget(m_groupOnInsertionLine);
hLayV->addWidget(helpV);
hLayV->insertStretch(-1);
- tqlayout->addWidget(m_groupOnInsertionLineWidget);
+ layout->addWidget(m_groupOnInsertionLineWidget);
connect(m_groupOnInsertionLine, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changed()));
widget = new TQWidget(behaviorBox);
@@ -594,7 +594,7 @@ BasketsPage::BasketsPage(TQWidget * parent, const char * name)
// Protection:
TQGroupBox *protectionBox = new TQGroupBox(3, Qt::Vertical, i18n("Password Protection"), this);
- tqlayout->addWidget(protectionBox);
+ layout->addWidget(protectionBox);
widget = new TQWidget(protectionBox);
// Re-Lock timeout configuration
@@ -608,7 +608,7 @@ BasketsPage::BasketsPage(TQWidget * parent, const char * name)
//label = new TQLabel(i18n("minutes"), this);
//hLay->addWidget(label);
hLay->addStretch();
-// tqlayout->addLayout(hLay);
+// layout->addLayout(hLay);
connect( m_enableReLockTimeoutMinutes, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changed()) );
connect( m_reLockTimeoutMinutes, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(changed()) );
connect( m_enableReLockTimeoutMinutes, TQT_SIGNAL(toggled(bool)), m_reLockTimeoutMinutes, TQT_SLOT(setEnabled(bool)) );
@@ -619,7 +619,7 @@ BasketsPage::BasketsPage(TQWidget * parent, const char * name)
connect( m_useGnuPGAgent, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changed()) );
#endif
- tqlayout->insertStretch(-1);
+ layout->insertStretch(-1);
load();
}
@@ -682,7 +682,7 @@ void BasketsPage::defaults()
NewNotesPage::NewNotesPage(TQWidget * parent, const char * name)
: KCModule(parent, name)
{
- TQVBoxLayout *tqlayout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
+ TQVBoxLayout *layout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
TQHBoxLayout *hLay;
TQLabel *label;
@@ -697,7 +697,7 @@ NewNotesPage::NewNotesPage(TQWidget * parent, const char * name)
hLay->addWidget(label);
hLay->addWidget(m_newNotesPlace);
hLay->addStretch();
- //tqlayout->addLayout(hLay);
+ //layout->addLayout(hLay);
label->hide();
m_newNotesPlace->hide();
connect( m_newNotesPlace, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(changed()) );
@@ -726,7 +726,7 @@ NewNotesPage::NewNotesPage(TQWidget * parent, const char * name)
m_pushVisualize = new TQPushButton(i18n("&Visualize..."), this);
hLay->addWidget(m_pushVisualize);
hLay->addStretch();
- tqlayout->addLayout(hLay);
+ layout->addLayout(hLay);
connect( m_pushVisualize, TQT_SIGNAL(clicked()), this, TQT_SLOT(visualize()) );
// View File Content:
@@ -736,13 +736,13 @@ NewNotesPage::NewNotesPage(TQWidget * parent, const char * name)
m_viewHtmlFileContent = new TQCheckBox( i18n("&HTML page"), buttonGroup );
m_viewImageFileContent = new TQCheckBox( i18n("&Image or animation"), buttonGroup );
m_viewSoundFileContent = new TQCheckBox( i18n("&Sound"), buttonGroup );
- tqlayout->addWidget(buttonGroup);
+ layout->addWidget(buttonGroup);
connect( m_viewTextFileContent, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changed()) );
connect( m_viewHtmlFileContent, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changed()) );
connect( m_viewImageFileContent, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changed()) );
connect( m_viewSoundFileContent, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changed()) );
- tqlayout->insertStretch(-1);
+ layout->insertStretch(-1);
load();
}
@@ -790,9 +790,9 @@ void NewNotesPage::visualize()
NotesAppearancePage::NotesAppearancePage(TQWidget * parent, const char * name)
: KCModule(parent, name)
{
- TQVBoxLayout *tqlayout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
+ TQVBoxLayout *layout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
TQTabWidget *tabs = new TQTabWidget(this);
- tqlayout->addWidget(tabs);
+ layout->addWidget(tabs);
m_soundLook = new LinkLookEditWidget(this, i18n("Conference audio record"), "sound", tabs);
m_fileLook = new LinkLookEditWidget(this, i18n("Annual report"), "document", tabs);
@@ -838,7 +838,7 @@ ApplicationsPage::ApplicationsPage(TQWidget * parent, const char * name)
: KCModule(parent, name)
{
/* Applications page */
- TQVBoxLayout *tqlayout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
+ TQVBoxLayout *layout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
m_htmlUseProg = new TQCheckBox(i18n("Open &text notes with a custom application:"), this);
m_htmlProg = new RunCommandRequester("", i18n("Open text notes with:"), this);
@@ -890,16 +890,16 @@ ApplicationsPage::ApplicationsPage(TQWidget * parent, const char * name)
TQWhatsThis::add(m_animationProg, whatsthis);
TQWhatsThis::add(m_soundProg, whatsthis);
- tqlayout->addWidget(m_htmlUseProg);
- tqlayout->addItem(hLayH);
- tqlayout->addWidget(m_imageUseProg);
- tqlayout->addItem(hLayI);
- tqlayout->addWidget(m_animationUseProg);
- tqlayout->addItem(hLayA);
- tqlayout->addWidget(m_soundUseProg);
- tqlayout->addItem(hLayS);
+ layout->addWidget(m_htmlUseProg);
+ layout->addItem(hLayH);
+ layout->addWidget(m_imageUseProg);
+ layout->addItem(hLayI);
+ layout->addWidget(m_animationUseProg);
+ layout->addItem(hLayA);
+ layout->addWidget(m_soundUseProg);
+ layout->addItem(hLayS);
- tqlayout->addSpacing(KDialogBase::spacingHint());
+ layout->addSpacing(KDialogBase::spacingHint());
TQHBoxLayout *hLay = new TQHBoxLayout(0L, /*margin=*/0, /*spacing=*/0);
HelpLabel *hl1 = new HelpLabel(
@@ -918,7 +918,7 @@ ApplicationsPage::ApplicationsPage(TQWidget * parent, const char * name)
this);
hLay->addWidget(hl1);
hLay->addStretch();
- tqlayout->addLayout(hLay);
+ layout->addLayout(hLay);
hLay = new TQHBoxLayout(0L, /*margin=*/0, /*spacing=*/0);
HelpLabel *hl2 = new HelpLabel(
@@ -938,14 +938,14 @@ ApplicationsPage::ApplicationsPage(TQWidget * parent, const char * name)
this);
hLay->addWidget(hl2);
hLay->addStretch();
- tqlayout->addLayout(hLay);
+ layout->addLayout(hLay);
connect( m_htmlUseProg, TQT_SIGNAL(toggled(bool)), m_htmlProg, TQT_SLOT(setEnabled(bool)) );
connect( m_imageUseProg, TQT_SIGNAL(toggled(bool)), m_imageProg, TQT_SLOT(setEnabled(bool)) );
connect( m_animationUseProg, TQT_SIGNAL(toggled(bool)), m_animationProg, TQT_SLOT(setEnabled(bool)) );
connect( m_soundUseProg, TQT_SIGNAL(toggled(bool)), m_soundProg, TQT_SLOT(setEnabled(bool)) );
- tqlayout->insertStretch(-1);
+ layout->insertStretch(-1);
load();
}
diff --git a/src/softwareimporters.cpp b/src/softwareimporters.cpp
index 84dd628..520aec4 100644
--- a/src/softwareimporters.cpp
+++ b/src/softwareimporters.cpp
@@ -216,7 +216,7 @@ void SoftwareImporters::finishImport(Basket *basket)
// Focus the FIRST note (the last inserted note is currently focused!):
basket->setFocusedNote(basket->firstNoteShownInStack());
- // Retqlayout every notes at theire new place and simulate a load animation (because already loaded just after the creation).
+ // Relayout every notes at theire new place and simulate a load animation (because already loaded just after the creation).
// Without a relayouting, notes on the bottom would comes from the top (because they were inserted on top) and clutter the animation load:
basket->relayoutNotes(/*animate=*/false);
basket->animateLoad();
diff --git a/src/systemtray.cpp b/src/systemtray.cpp
index 118d449..990e42e 100644
--- a/src/systemtray.cpp
+++ b/src/systemtray.cpp
@@ -161,7 +161,7 @@ void KSystemTray2::displayCloseMessage(TQString fileMenu)
const int IMAGE_BORDER = 1;
int ax = g.x() - x - CIRCLE_MARGINS - 1;
int ay = g.y() - y - CIRCLE_MARGINS - 1;
- painter.setPen( TQPen(KApplication::tqpalette().active().dark(), CIRCLE_WIDTH) );
+ painter.setPen( TQPen(KApplication::palette().active().dark(), CIRCLE_WIDTH) );
painter.drawArc(ax + SHADOW_OFFSET, ay + SHADOW_OFFSET,
tw + 2*CIRCLE_MARGINS, th + 2*CIRCLE_MARGINS, 0, 16*360);
painter.setPen( TQPen(TQt::red/*KApplication::tqpalette().active().highlight()*/, CIRCLE_WIDTH) );
@@ -174,7 +174,7 @@ void KSystemTray2::displayCloseMessage(TQString fileMenu)
// Then, we add a border arround the image to make it more visible:
TQPixmap finalShot(w + 2*IMAGE_BORDER, h + 2*IMAGE_BORDER);
- finalShot.fill(KApplication::tqpalette().active().foreground());
+ finalShot.fill(KApplication::palette().active().foreground());
painter.begin(&finalShot);
painter.drawPixmap(IMAGE_BORDER, IMAGE_BORDER, shot);
painter.end();
diff --git a/src/tag.cpp b/src/tag.cpp
index 700b88e..1dce82b 100644
--- a/src/tag.cpp
+++ b/src/tag.cpp
@@ -736,7 +736,7 @@ void IndentedMenuItem::paint(TQPainter *painter, const TQColorGroup &cg, bool ac
*/
bool drawingEtchedText = !enabled && !active && painter->pen().color() != cg.mid()/*== cg.foreground()*/;
if (drawingEtchedText) {
- TQString styleName = kapp->tqstyle().name();
+ TQString styleName = kapp->style().name();
if (styleName == "plastik" || styleName == "lipstik")
painter->setPen(cg.light());
drawingEtchedText = !enabled && !active && painter->pen().color() != cg.foreground();
@@ -806,7 +806,7 @@ void StateMenuItem::paint(TQPainter *painter, const TQColorGroup &cg, bool activ
*/
bool drawingEtchedText = !enabled && !active && painter->pen().color() != cg.mid()/*== cg.foreground()*/;
if (drawingEtchedText) {
- TQString styleName = kapp->tqstyle().name();
+ TQString styleName = kapp->style().name();
if (styleName == "plastik" || styleName == "lipstik")
painter->setPen(cg.light());
drawingEtchedText = !enabled && !active && painter->pen().color() != cg.foreground();
@@ -851,11 +851,11 @@ TQSize StateMenuItem::sizeHint()
TQIconSet StateMenuItem::checkBoxIconSet(bool checked, TQColorGroup cg)
{
- int width = kapp->tqstyle().pixelMetric(TQStyle::PM_IndicatorWidth, 0);
- int height = kapp->tqstyle().pixelMetric(TQStyle::PM_IndicatorHeight, 0);
+ int width = kapp->style().pixelMetric(TQStyle::PM_IndicatorWidth, 0);
+ int height = kapp->style().pixelMetric(TQStyle::PM_IndicatorHeight, 0);
TQRect rect(0, 0, width, height);
- TQColor menuBackgroundColor = (dynamic_cast<KStyle*>(&(kapp->tqstyle())) == NULL ? TQColor(cg.background()) : cg.background().light(103));
+ TQColor menuBackgroundColor = (dynamic_cast<KStyle*>(&(kapp->style())) == NULL ? TQColor(cg.background()) : cg.background().light(103));
// Enabled, Not hovering
TQPixmap pixmap(width, height);
@@ -863,7 +863,7 @@ TQIconSet StateMenuItem::checkBoxIconSet(bool checked, TQColorGroup cg)
TQPainter painter(&pixmap);
int style = TQStyle::Style_Enabled | TQStyle::Style_Active | (checked ? TQStyle::Style_On : TQStyle::Style_Off);
TQColor background = cg.color(TQColorGroup::Background);
- kapp->tqstyle().tqdrawPrimitive(TQStyle::PE_Indicator, &painter, rect, cg, style);
+ kapp->style().tqdrawPrimitive(TQStyle::PE_Indicator, &painter, rect, cg, style);
painter.end();
// Enabled, Hovering
@@ -872,7 +872,7 @@ TQIconSet StateMenuItem::checkBoxIconSet(bool checked, TQColorGroup cg)
painter.begin(&pixmapHover);
style |= TQStyle::Style_MouseOver;
cg.setColor(TQColorGroup::Background, KGlobalSettings::highlightColor());
- kapp->tqstyle().tqdrawPrimitive(TQStyle::PE_Indicator, &painter, rect, cg, style);
+ kapp->style().tqdrawPrimitive(TQStyle::PE_Indicator, &painter, rect, cg, style);
painter.end();
// Disabled
@@ -881,7 +881,7 @@ TQIconSet StateMenuItem::checkBoxIconSet(bool checked, TQColorGroup cg)
painter.begin(&pixmapDisabled);
style = /*TQStyle::Style_Enabled | */TQStyle::Style_Active | (checked ? TQStyle::Style_On : TQStyle::Style_Off);
cg.setColor(TQColorGroup::Background, background);
- kapp->tqstyle().tqdrawPrimitive(TQStyle::PE_Indicator, &painter, rect, cg, style);
+ kapp->style().tqdrawPrimitive(TQStyle::PE_Indicator, &painter, rect, cg, style);
painter.end();
TQIconSet iconSet(pixmap);
@@ -892,8 +892,8 @@ TQIconSet StateMenuItem::checkBoxIconSet(bool checked, TQColorGroup cg)
TQIconSet StateMenuItem::radioButtonIconSet(bool checked, TQColorGroup cg)
{
- int width = kapp->tqstyle().pixelMetric(TQStyle::PM_ExclusiveIndicatorWidth, 0);
- int height = kapp->tqstyle().pixelMetric(TQStyle::PM_ExclusiveIndicatorHeight, 0);
+ int width = kapp->style().pixelMetric(TQStyle::PM_ExclusiveIndicatorWidth, 0);
+ int height = kapp->style().pixelMetric(TQStyle::PM_ExclusiveIndicatorHeight, 0);
TQRect rect(0, 0, width, height);
int style = TQStyle::Style_Default | TQStyle::Style_Enabled | (checked ? TQStyle::Style_On : TQStyle::Style_Off);
@@ -902,13 +902,13 @@ TQIconSet StateMenuItem::radioButtonIconSet(bool checked, TQColorGroup cg)
pixmap.fill(TQt::red);
TQPainter painter(&pixmap);
/* We can't use that line of code (like for checkboxes):
- * //kapp->tqstyle().tqdrawPrimitive(TQStyle::PE_ExclusiveIndicator, &painter, rect, cg, style);
+ * //kapp->style().tqdrawPrimitive(TQStyle::PE_ExclusiveIndicator, &painter, rect, cg, style);
* because Plastik (and derived styles) don't care of the TQStyle::Style_On flag and will ALWAYS draw an unchecked radiobutton.
* So, we use another method:
*/
TQRadioButton rb(0);
rb.setChecked(checked);
- kapp->tqstyle().drawControl(TQStyle::CE_RadioButton, &painter, &rb, rect, cg, style);
+ kapp->style().drawControl(TQStyle::CE_RadioButton, &painter, &rb, rect, cg, style);
painter.end();
/* Some styles like Plastik (and derived ones) have TQStyle::PE_ExclusiveIndicator drawing a radiobutton disc, as wanted,
* and leave pixels ouside it untouched, BUT TQStyle::PE_ExclusiveIndicatorMask is a fully black square.
@@ -921,10 +921,10 @@ TQIconSet StateMenuItem::radioButtonIconSet(bool checked, TQColorGroup cg)
TQPixmap pixmapHover(width, height);
pixmapHover.fill(TQt::red);
painter.begin(&pixmapHover);
- //kapp->tqstyle().tqdrawPrimitive(TQStyle::PE_ExclusiveIndicator, &painter, rect, cg, style);
+ //kapp->style().tqdrawPrimitive(TQStyle::PE_ExclusiveIndicator, &painter, rect, cg, style);
style |= TQStyle::Style_MouseOver;
cg.setColor(TQColorGroup::Background, KGlobalSettings::highlightColor());
- kapp->tqstyle().drawControl(TQStyle::CE_RadioButton, &painter, &rb, rect, cg, style);
+ kapp->style().drawControl(TQStyle::CE_RadioButton, &painter, &rb, rect, cg, style);
painter.end();
pixmapHover.setMask(pixmapHover.createHeuristicMask());
diff --git a/src/tagsedit.cpp b/src/tagsedit.cpp
index ff6a6eb..fb935c1 100644
--- a/src/tagsedit.cpp
+++ b/src/tagsedit.cpp
@@ -326,7 +326,7 @@ TagsEditDialog::TagsEditDialog(TQWidget *parent, State *stateToEdit, bool addNew
KDialogBase::Ok, parent, /*name=*/"CustomizeTags", /*modal=*/true, /*separator=*/true),
m_loading(false)
{
- TQHBoxLayout *tqlayout = new TQHBoxLayout(plainPage(), /*margin=*/0, spacingHint());
+ TQHBoxLayout *layout = new TQHBoxLayout(plainPage(), /*margin=*/0, spacingHint());
/* Left part: */
@@ -366,7 +366,7 @@ TagsEditDialog::TagsEditDialog(TQWidget *parent, State *stateToEdit, bool addNew
leftLayout->addWidget(m_tags);
leftLayout->addLayout(topLeftLayout);
- tqlayout->addLayout(leftLayout);
+ layout->addLayout(leftLayout);
/* Right part: */
@@ -540,7 +540,7 @@ TagsEditDialog::TagsEditDialog(TQWidget *parent, State *stateToEdit, bool addNew
rightLayout->addWidget(m_stateBox);
rightLayout->addStretch();
- tqlayout->addWidget(rightWidget);
+ layout->addWidget(rightWidget);
rightWidget->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::Expanding);
// Equalize the width of the first column of the two grids:
diff --git a/src/variouswidgets.cpp b/src/variouswidgets.cpp
index 529a961..705aa98 100644
--- a/src/variouswidgets.cpp
+++ b/src/variouswidgets.cpp
@@ -42,14 +42,14 @@ RunCommandRequester::RunCommandRequester(const TQString &runCommand, const TQStr
{
m_message = message;
- TQHBoxLayout *tqlayout = new TQHBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
+ TQHBoxLayout *layout = new TQHBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
m_runCommand = new TQLineEdit(runCommand, this);
TQPushButton *pb = new TQPushButton(/*"C&hoose..."*/i18n("..."), this);
pb->setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed);
- tqlayout->addWidget(m_runCommand);
- tqlayout->addWidget(pb);
+ layout->addWidget(m_runCommand);
+ layout->addWidget(pb);
connect( pb, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotSelCommand()) );
}
diff --git a/src/kcolorcombo2.cpp b/src/kcolorcombo2.cpp
index cd57f25..04f1b43 100644
--- a/src/kcolorcombo2.cpp
+++ b/src/kcolorcombo2.cpp
@@ -68,7 +68,7 @@ KColorPopup::~KColorPopup()
#include <tqcursor.h>
-void KColorPopup::retqlayout() // FIXME: retqlayout should NOT redraw the pixmap!
+void KColorPopup::relayout() // FIXME: relayout should NOT redraw the pixmap!
{
int columnCount = m_selector->columnCount();
int rowCount = m_selector->rowCount();
@@ -240,7 +240,7 @@ void KColorPopup::mouseMoveEvent(TQMouseEvent *event)
m_selectedColumn = (x - FRAME_WIDTH - MARGIN + 2) / (colorWidth + MARGIN);
m_selectedRow = (y - FRAME_WIDTH - MARGIN + 2) / (colorHeight + MARGIN);
- retqlayout();
+ relayout();
update();
}
@@ -288,7 +288,7 @@ void KColorPopup::keyPressEvent(TQKeyEvent *event)
if (row != m_selectedRow || column != m_selectedColumn) {
m_selectedRow = row;
m_selectedColumn = column;
- retqlayout();
+ relayout();
update();
}
}
@@ -491,7 +491,7 @@ void KColorCombo2::newColorArray(int columnCount, int rowCount)
for (int i = 0; i < columnCount; ++i)
m_colorArray[i] = new TQColor[rowCount];
- m_popup->retqlayout();
+ m_popup->relayout();
}
void KColorCombo2::setColorAt(int column, int row, const TQColor &color)
@@ -654,7 +654,7 @@ void KColorCombo2::popup()
m_popup->move(popupPoint);
//m_popup->setColor(m_color);
m_popup->doSelection();
- m_popup->retqlayout(); // FIXME: In aboutToShow() ?
+ m_popup->relayout(); // FIXME: In aboutToShow() ?
#if 0
//#ifndef TQT_NO_EFFECTS
if (TQApplication::isEffectEnabled(UI_AnimateCombo)) {
@@ -745,10 +745,10 @@ void KColorCombo2::keyPressEvent(TQKeyEvent *event)
if (KStdAccel::copy().contains(key)) {
TQMimeSource *mime = new KColorDrag(effectiveColor());
- TQApplication::tqclipboard()->setData(mime, TQClipboard::Clipboard);
+ TQApplication::clipboard()->setData(mime, TQClipboard::Clipboard);
} else if (KStdAccel::paste().contains(key)) {
TQColor color;
- KColorDrag::decode(TQApplication::tqclipboard()->data(TQClipboard::Clipboard), color);
+ KColorDrag::decode(TQApplication::clipboard()->data(TQClipboard::Clipboard), color);
setColor(color);
} else
TQComboBox::keyPressEvent(event);
diff --git a/src/notecontent.cpp b/src/notecontent.cpp
index 4ba09d1..02fc97a 100644
--- a/src/notecontent.cpp
+++ b/src/notecontent.cpp
@@ -138,7 +138,7 @@ void NoteContent::contentChanged(int newMinWidth)
m_minWidth = newMinWidth;
if (note()) {
// note()->unbufferize();
- note()->requestRetqlayout(); // TODO: It should re-set the width! m_width = 0 ? contentChanged: setWidth, geteight, if size havent changed, only repaint and not retqlayout
+ note()->requestRelayout(); // TODO: It should re-set the width! m_width = 0 ? contentChanged: setWidth, geteight, if size havent changed, only repaint and not relayout
}
}
@@ -942,7 +942,7 @@ void AnimationContent::movieUpdated(const TQRect&)
void AnimationContent::movieResized(const TQSize&)
{
- note()->requestRetqlayout(); // ?
+ note()->requestRelayout(); // ?
}
/** When a user drop a .gif file, for instance, we don't know if it is an image